@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.3.11
+# Version   : 0.3.13
 
 from operator import contains
 import  numpy                   as      np
@@ -1171,7 +1171,7 @@ class AFM:
             indent_fit = LinearRegression(fit_intercept = intercept)
 
             x = depth
-            y = force
+            y = np.sqrt(force)
 
             x = x[~np.isnan(y)]
             y = y[~np.isnan(y)]
@@ -1182,18 +1182,23 @@ class AFM:
             x = x.reshape(-1, 1)
             y = y.reshape(-1, 1)
 
+            if len(x) == 0:
 
-            indent_fit.fit(x, y)
+                self.modulus[curve_number] = np.nan
+                
+            else:
 
-            c = indent_fit.coef_
+                indent_fit.fit(x, y)
 
-            term_1 = np.pi/2
-            term_2 = 1 / np.tan(np.deg2rad(opening_angle))
-            term_3 = (1 - np.array(poisson_ratio) ** 2)
+                c = indent_fit.coef_
 
-            E = c ** 2 * term_1 * term_2 * term_3  * 1e-6
+                term_1 = np.pi/2
+                term_2 = 1 / np.tan(np.deg2rad(opening_angle))
+                term_3 = (1 - np.array(poisson_ratio) ** 2)
 
-            self.modulus[curve_number] = E
+                E = c ** 2 * term_1 * term_2 * term_3  * 1e-6
+
+                self.modulus[curve_number] = E
         
         if plot_hist is True:
             fig = go.Figure(data=[go.Histogram(x = self.modulus)])
